pub fn slice_owner(path: &str) -> Option<SliceOwner>Expand description
Returns the owner of a given cgroup path.
Returns None for paths outside the known hierarchy (e.g., root cgroup).
pub fn slice_owner(path: &str) -> Option<SliceOwner>Returns the owner of a given cgroup path.
Returns None for paths outside the known hierarchy (e.g., root cgroup).