Module namespace

Module namespace 

Namespace handoff protocol.

Defines the protocol for passing Linux namespace file descriptors between pact-agent (provider) and lattice-node-agent (consumer) via unix socket with SCM_RIGHTS.

Structs

AllocationEnded
Notification that an allocation has ended.
NamespaceRequest
Request from lattice to pact for allocation namespaces.
NamespaceResponse
Response from pact to lattice with namespace metadata.

Enums

NamespaceError
Errors from namespace operations.
NamespaceType
Namespace types that can be created and handed off.

Constants

HANDOFF_SOCKET_PATH
Well-known socket path for namespace handoff.

Traits

NamespaceConsumer
Trait for the namespace handoff consumer (lattice-node-agent implements).
NamespaceProvider
Trait for the namespace handoff provider (pact-agent implements).