pub struct AllocationEnded {
pub allocation_id: String,
}Expand description
Notification that an allocation has ended.
Sent when pact detects that all processes in the allocation’s cgroup have exited (WI5: cgroup-empty detection). Lattice can also send this proactively if it knows the allocation ended.
Fields
allocation_id: StringAllocation identifier.