pub struct NamespaceRequest {
pub allocation_id: String,
pub namespaces: Vec<NamespaceType>,
pub uenv_image: Option<String>,
}Expand description
Request from lattice to pact for allocation namespaces.
Sent over the handoff unix socket as a framed message.
Fields
allocation_id: StringAllocation identifier (from lattice scheduler).
namespaces: Vec<NamespaceType>Which namespaces to create.
uenv_image: Option<String>Optional uenv image to mount inside the mount namespace.