cgroup v2 conventions and management trait.
Defines the shared cgroup hierarchy layout that both pact and lattice use, regardless of which system creates it.
Modules
- slices
- Well-known cgroup slice paths.
Structs
- Cgroup
Handle - Opaque handle to a created cgroup scope.
- Cgroup
Metrics - Metrics read from a cgroup.
- Resource
Limits - Resource limits for a cgroup scope.
Enums
- Cgroup
Error - Errors from cgroup operations.
- Slice
Owner - cgroup slice ownership — who has exclusive write access.
Traits
- Cgroup
Manager - Trait for cgroup hierarchy management.
Functions
- slice_
owner - Returns the owner of a given cgroup path.