Namespace handoff protocol.
Defines the protocol for passing Linux namespace file descriptors between
pact-agent (provider) and lattice-node-agent (consumer) via unix socket
with SCM_RIGHTS.
Structs
- Allocation
Ended - Notification that an allocation has ended.
- Namespace
Request - Request from lattice to pact for allocation namespaces.
- Namespace
Response - Response from pact to lattice with namespace metadata.
Enums
- Namespace
Error - Errors from namespace operations.
- Namespace
Type - Namespace types that can be created and handed off.
Constants
- HANDOFF_
SOCKET_ PATH - Well-known socket path for namespace handoff.
Traits
- Namespace
Consumer - Trait for the namespace handoff consumer (lattice-node-agent implements).
- Namespace
Provider - Trait for the namespace handoff provider (pact-agent implements).